==> graph-generators-0.1.4.tar.gz: graph-generators-0.1.4/README.md <==
# graph-generators
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Python functions to compute various classes of `networkx` graphs

## Requirements
Requires `python >= 3.5` and `networkx`.

## Installation
`pip install graph-generators`

## Usage
After installation, run `from graph_generators.graph_generators import *`

For instance, `keller_graph(n)` returns an _n_-dimensional Keller graph.

## List of graphs

| Graph name     | Function name |
|---------|---------------|
| [Keller graph](https://mathworld.wolfram.com/KellerGraph.html) | `keller_graph` |
| [King graph](https://mathworld.wolfram.com/KingGraph.html) | `king_graph` |
| [Knight graph](https://mathworld.wolfram.com/KnightGraph.html) | `knight_graph` |
| [Antelope graph](https://mathworld.wolfram.com/AntelopeGraph.html) | `antelope_graph` |
| [Fiveleaper graph](https://mathworld.wolfram.com/FiveleaperGraph.html) | `fiveleaper_graph` |
| [Prism graph](https://mathworld.wolfram.com/PrismGraph.html) | `prism_graph` |
| [Moebius ladder graph](https://mathworld.wolfram.com/MoebiusLadder.html) | `mobius_ladder_graph` |
| [Book graph](https://mathworld.wolfram.com/BookGraph.html) | `book_graph` |
| [Stacked book graph](https://mathworld.wolfram.com/StackedBookGraph.html) | `stacked_book_graph` |
| [Odd graph](https://mathworld.wolfram.com/OddGraph.html) | `odd_graph` |
| [Fibonacci cube graph](https://mathworld.wolfram.com/FibonacciCubeGraph.html) | `fibonacci_cube_graph` |
| [Lucas cube graph](https://mathworld.wolfram.com/LucasCubeGraph.html) | `lucas_cube_graph` |
| [Halved cube graph](https://mathworld.wolfram.com/HalvedCubeGraph.html) | `halved_cube_graph` |
| [Folded cube graph](https://mathworld.wolfram.com/FoldedCubeGraph.html) | `folded_cube_graph` |

==> graph-generators-0.1.5.tar.gz: graph-generators-0.1.5/README.md <==
# graph-generators
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Python functions to compute various classes of `networkx` graphs

## Requirements
Requires `python >= 3.5` and `networkx`.

## Installation
`pip install graph-generators`

## Usage
After installation, run `from graph_generators import *`

For instance, `keller_graph(n)` returns an _n_-dimensional Keller graph.

## List of graphs

| Graph name     | Function name |
|---------|---------------|
| [Keller graph](https://mathworld.wolfram.com/KellerGraph.html) | `keller_graph` |
| [King graph](https://mathworld.wolfram.com/KingGraph.html) | `king_graph` |
| [Knight graph](https://mathworld.wolfram.com/KnightGraph.html) | `knight_graph` |
| [Antelope graph](https://mathworld.wolfram.com/AntelopeGraph.html) | `antelope_graph` |
| [Fiveleaper graph](https://mathworld.wolfram.com/FiveleaperGraph.html) | `fiveleaper_graph` |
| [Prism graph](https://mathworld.wolfram.com/PrismGraph.html) | `prism_graph` |
| [Moebius ladder graph](https://mathworld.wolfram.com/MoebiusLadder.html) | `mobius_ladder_graph` |
| [Book graph](https://mathworld.wolfram.com/BookGraph.html) | `book_graph` |
| [Stacked book graph](https://mathworld.wolfram.com/StackedBookGraph.html) | `stacked_book_graph` |
| [Odd graph](https://mathworld.wolfram.com/OddGraph.html) | `odd_graph` |
| [Fibonacci cube graph](https://mathworld.wolfram.com/FibonacciCubeGraph.html) | `fibonacci_cube_graph` |
| [Lucas cube graph](https://mathworld.wolfram.com/LucasCubeGraph.html) | `lucas_cube_graph` |
| [Halved cube graph](https://mathworld.wolfram.com/HalvedCubeGraph.html) | `halved_cube_graph` |
| [Folded cube graph](https://mathworld.wolfram.com/FoldedCubeGraph.html) | `folded_cube_graph` |
